@@ -6,10 +6,11 @@ import pylab as pl
 import sciris as sc
 
 torun = [
-'hex2rgb',
-'gridcolors',
-'surf3d',
-'bar3d',
+# 'hex2rgb',
+'arraycolors',
+# 'gridcolors',
+# 'surf3d',
+# 'bar3d',
 ]
 
 if 'doplot' not in locals(): doplot = True
@@ -18,6 +19,21 @@ if 'hex2rgb' in torun:
     c1 = sc.hex2rgb('#fff')
     c2 = sc.hex2rgb('fabcd8')
 
+if 'arraycolors' in torun:
+    n = 1000
+    ncols = 5
+    arr = pl.rand(n,ncols)
+    for c in range(ncols):
+        arr[:,c] += c
+    x = pl.rand(n)
+    y = pl.rand(n)
+    colors = sc.arraycolors(arr)
+    if doplot:
+        pl.figure(figsize=(20,16))
+        for c in range(ncols):
+            pl.scatter(x+c, y, s=50, c=colors[:,c])
+
+
 if 'gridcolors' in torun:
     colors_a = sc.gridcolors(ncolors=8,  demo=doplot)
     colors_b = sc.gridcolors(ncolors=18, demo=doplot)
